@@ -1,4 +1,6 @@
-while read i;
+#!/bin/sh
+
+while read -r i;
 do
   echo "$i" | python -m json.tool ;
-done < $1
+done < "$1"
