@@ -1,4 +1,3 @@
-#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 import argparse
 import datetime
@@ -172,10 +171,12 @@ class IntelMQProcessManager:
         with open(filename, 'w') as fp:
             fp.write(str(os.getpid()))
 
+        output = ""
         try:
-            BotDebugger(self.__runtime_configuration[bot_id], bot_id, run_subcommand,
-                        console_type, message_action_kind, dryrun, msg, show_sent,
-                        loglevel=loglevel)
+            bd = BotDebugger(self.__runtime_configuration[bot_id], bot_id, run_subcommand,
+                             console_type, message_action_kind, dryrun, msg, show_sent,
+                             loglevel=loglevel)
+            output = bd.run()
             retval = 0
         except KeyboardInterrupt:
             print('Keyboard interrupt.')
@@ -187,7 +188,8 @@ class IntelMQProcessManager:
         self.__remove_pidfile(bot_id)
         if paused:
             self.bot_start(bot_id)
-        return retval
+
+        return retval, output
 
     def bot_start(self, bot_id, getstatus=True):
         pid = self.__check_pid(bot_id)
@@ -464,10 +466,12 @@ class SupervisorProcessManager:
 
         log_bot_message("starting", bot_id)
 
+        output = ""
         try:
-            BotDebugger(self.__runtime_configuration[bot_id], bot_id, run_subcommand,
-                        console_type, message_action_kind, dryrun, msg, show_sent,
-                        loglevel=loglevel)
+            bd = BotDebugger(self.__runtime_configuration[bot_id], bot_id, run_subcommand,
+                             console_type, message_action_kind, dryrun, msg, show_sent,
+                             loglevel=loglevel)
+            output = bd.run()
             retval = 0
         except KeyboardInterrupt:
             print("Keyboard interrupt.")
@@ -479,7 +483,7 @@ class SupervisorProcessManager:
         if paused:
             self.bot_start(bot_id)
 
-        return retval
+        return retval, output
 
     def bot_start(self, bot_id: str, getstatus: bool = True):
         state = self._get_process_state(bot_id)
@@ -682,6 +686,7 @@ class IntelMQController():
             no_file_logging: do not log to the log file
             drop_privileges: Drop privileges and fail if it did not work.
         """
+        self.logging_level = DEFAULT_LOGGING_LEVEL
         self.interactive = interactive
         global RETURN_TYPE
         RETURN_TYPE = return_type
@@ -690,31 +695,33 @@ class IntelMQController():
         QUIET = quiet
         self.parameters = Parameters()
 
-        # Try to get log_level from defaults_configuration, else use default
+        # Try to get logging_level from defaults configuration, else use default (defined above)
         defaults_loading_exc = None
         try:
             self.load_defaults_configuration()
         except Exception as exc:
             defaults_loading_exc = exc
-            log_level = DEFAULT_LOGGING_LEVEL
             logging_level_stream = 'DEBUG'
         else:
-            log_level = self.parameters.logging_level.upper()
+            self.logging_level = self.parameters.logging_level.upper()
         # make sure that logging_level_stream is always at least INFO or more verbose
         # otherwise the output on stdout/stderr is less than the user expects
-        logging_level_stream = log_level if log_level == 'DEBUG' else 'INFO'
+        logging_level_stream = self.logging_level if self.logging_level == 'DEBUG' else 'INFO'
 
         try:
             if no_file_logging:
-                raise FileNotFoundError
-            logger = utils.log('intelmqctl', log_level=log_level,
+                raise FileNotFoundError('Logging to file disabled.')
+            logger = utils.log('intelmqctl', log_level=self.logging_level,
                                log_format_stream=utils.LOG_FORMAT_SIMPLE,
-                               logging_level_stream=logging_level_stream)
+                               logging_level_stream=logging_level_stream,
+                               log_max_size=getattr(self.parameters, "logging_max_size", 0),
+                               log_max_copies=getattr(self.parameters, "logging_max_copies", None))
         except (FileNotFoundError, PermissionError) as exc:
-            logger = utils.log('intelmqctl', log_level=log_level, log_path=False,
+            logger = utils.log('intelmqctl', log_level=self.logging_level, log_path=False,
                                log_format_stream=utils.LOG_FORMAT_SIMPLE,
                                logging_level_stream=logging_level_stream)
-            logger.error('Not logging to file: %s', exc)
+            if not isinstance(exc, FileNotFoundError) and exc.args[0] != 'Logging to file disabled.':
+                logger.error('Not logging to file: %s', exc)
         self.logger = logger
         if defaults_loading_exc:
             self.logger.exception('Loading the defaults configuration failed!',
@@ -801,7 +808,7 @@ Upgrade from a previous version:
     intelmqctl upgrade-config
 Make a backup of your configuration first, also including bot's configuration files.
 
-Get some debugging output on the settings and the enviroment (to be extended):
+Get some debugging output on the settings and the environment (to be extended):
     intelmqctl debug --get-paths
     intelmqctl debug --get-environment-variables
 '''
@@ -854,6 +861,10 @@ Get some debugging output on the settings and the enviroment (to be extended):
             parser_list.add_argument('--non-zero', '--quiet', '-q', action='store_true',
                                      help='Only list non-empty queues '
                                           'or the IDs of enabled bots.')
+            parser_list.add_argument('--count', '--sum', '-s', action='store_true',
+                                     help='Only show the total '
+                                          'number of messages in queues. '
+                                          'Only valid for listing queues.')
             parser_list.set_defaults(func=self.list)
 
             parser_clear = subparsers.add_parser('clear', help='Clear a queue')
@@ -1006,6 +1017,15 @@ Get some debugging output on the settings and the enviroment (to be extended):
         for option, value in config.items():
             setattr(self.parameters, option, value)
 
+        # TODO: Rewrite variables with env. variables ( CURRENT IMPLEMENTATION NOT FINAL )
+        # "destination_pipeline_host": "127.0.0.1",
+        # "source_pipeline_host": "127.0.0.1",
+        if os.getenv('INTELMQ_IS_DOCKER', None):
+            pipeline_host = os.getenv('INTELMQ_PIPELINE_HOST')
+            if pipeline_host:
+                setattr(self.parameters, 'destination_pipeline_host', pipeline_host)
+                setattr(self.parameters, 'source_pipeline_host', pipeline_host)
+
     def run(self):
         results = None
         args = self.parser.parse_args()
@@ -1026,7 +1046,12 @@ Get some debugging output on the settings and the enviroment (to be extended):
         return retval
 
     def bot_run(self, **kwargs):
-        return self.bot_process_manager.bot_run(**kwargs), None
+        # the bot_run method is special in that it mixes plain text
+        # and json in its output, therefore it is printed here
+        # and not in the calling `run` method.
+        retval, results = self.bot_process_manager.bot_run(**kwargs)
+        print(results)
+        return retval, None
 
     def bot_start(self, bot_id, getstatus=True, group=None):
         if bot_id is None:
@@ -1195,9 +1220,9 @@ Get some debugging output on the settings and the enviroment (to be extended):
                 retval = 1
         return retval, botnet_status
 
-    def list(self, kind=None, non_zero=False):
+    def list(self, kind=None, non_zero=False, count=False):
         if kind == 'queues':
-            return self.list_queues(non_zero=non_zero)
+            return self.list_queues(non_zero=non_zero, count=count)
         elif kind == 'bots':
             return self.list_bots(non_zero=non_zero)
         elif kind == 'queues-and-status':
@@ -1262,7 +1287,7 @@ Get some debugging output on the settings and the enviroment (to be extended):
 
         return source_queues, destination_queues, internal_queues, all_queues
 
-    def list_queues(self, non_zero=False):
+    def list_queues(self, non_zero=False, count=False):
         pipeline = PipelineFactory.create(self.parameters, logger=self.logger)
         pipeline.set_queues(None, "source")
         pipeline.connect()
@@ -1273,23 +1298,28 @@ Get some debugging output on the settings and the enviroment (to be extended):
         pipeline.disconnect()
         if RETURN_TYPE == 'text':
             for queue, counter in sorted(counters.items(), key=lambda x: str.lower(x[0])):
-                if counter or not non_zero:
+                if (counter or not non_zero) and not count:
                     logger.info("%s - %s", queue, counter)
+            if count:
+                logger.info("%s", sum(counters.values()))
 
         return_dict = {}
-        for bot_id, info in self.pipeline_configuration.items():
-            return_dict[bot_id] = {}
+        if count:
+            return_dict = {'total-messages': sum(counters.values())}
+        else:
+            for bot_id, info in self.pipeline_configuration.items():
+                return_dict[bot_id] = {}
 
-            if 'source-queue' in info:
-                return_dict[bot_id]['source_queue'] = (
-                    info['source-queue'], counters[info['source-queue']])
-                if pipeline.has_internal_queues:
-                    return_dict[bot_id]['internal_queue'] = counters[info['source-queue'] + '-internal']
+                if 'source-queue' in info:
+                    return_dict[bot_id]['source_queue'] = (
+                        info['source-queue'], counters[info['source-queue']])
+                    if pipeline.has_internal_queues:
+                        return_dict[bot_id]['internal_queue'] = counters[info['source-queue'] + '-internal']
 
-            if 'destination-queues' in info:
-                return_dict[bot_id]['destination_queues'] = []
-                for dest_queue in utils.flatten_queues(info['destination-queues']):
-                    return_dict[bot_id]['destination_queues'].append((dest_queue, counters[dest_queue]))
+                if 'destination-queues' in info:
+                    return_dict[bot_id]['destination_queues'] = []
+                    for dest_queue in utils.flatten_queues(info['destination-queues']):
+                        return_dict[bot_id]['destination_queues'].append((dest_queue, counters[dest_queue]))
 
         return 0, return_dict
 
@@ -1339,7 +1369,7 @@ Get some debugging output on the settings and the enviroment (to be extended):
         elif self.parameters.logging_handler == 'syslog':
             bot_log_path = '/var/log/syslog'
         else:
-            self.abort("Unknow logging handler %r" % self.parameters.logging_handler)
+            self.abort("Unknown logging handler %r" % self.parameters.logging_handler)
 
         if not os.access(bot_log_path, os.R_OK):
             self.logger.error('File %r is not readable.', bot_log_path)
@@ -1465,12 +1495,14 @@ Get some debugging output on the settings and the enviroment (to be extended):
                     else:
                         all_queues.add(files[PIPELINE_CONF_FILE][bot_id]['source-queue'])
                         all_queues.add(files[PIPELINE_CONF_FILE][bot_id]['source-queue'] + '-internal')
+        # ignore allowed orphaned queues
+        allowed_orphan_queues = set(getattr(self.parameters, 'intelmqctl_check_orphaned_queues_ignore', ()))
         if not no_connections:
             try:
                 pipeline = PipelineFactory.create(self.parameters, logger=self.logger)
                 pipeline.set_queues(None, "source")
                 pipeline.connect()
-                orphan_queues = "', '".join(pipeline.nonempty_queues() - all_queues)
+                orphan_queues = "', '".join(pipeline.nonempty_queues() - all_queues - allowed_orphan_queues)
             except Exception as exc:
                 error = utils.error_message_from_exc(exc)
                 check_logger.error('Could not connect to pipeline: %s', error)
@@ -1479,7 +1511,8 @@ Get some debugging output on the settings and the enviroment (to be extended):
                 if orphan_queues:
                     check_logger.warning("Orphaned queues found: '%s'. Possible leftover from past reconfigurations "
                                          "without cleanup. Have a look at the FAQ at "
-                                         "https://github.com/certtools/intelmq/blob/master/docs/FAQ.md", orphan_queues)
+                                         "https://intelmq.readthedocs.io/en/latest/guides/intelmqctl.html"
+                                         "#orphaned-queues", orphan_queues)
 
         check_logger.info('Checking harmonization configuration.')
         for event_type, event_type_conf in files[HARMONIZATION_CONF_FILE].items():
@@ -1517,7 +1550,7 @@ Get some debugging output on the settings and the enviroment (to be extended):
                 continue
             bot = getattr(bot_module, 'BOT')
             bot_parameters = files[DEFAULTS_CONF_FILE].copy()
-            bot_parameters.update(bot_config['parameters'])
+            bot_parameters.update(bot_config.get('parameters', {}))  # the parameters field may not exist
             bot_check = bot.check(bot_parameters)
             if bot_check:
                 for log_line in bot_check:
@@ -1600,7 +1633,7 @@ Get some debugging output on the settings and the enviroment (to be extended):
             We create the state file directly before any upgrade function.
             Otherwise we might run into the situation, that we can't write the state but we already upgraded.
             """
-            self.logger.info('Writing intial state file.')
+            self.logger.info('Writing initial state file.')
             state = {"version_history": [],
                      "upgrades": {},
                      "results": []}
