@@ -9,6 +9,8 @@ import hashlib
 import hmac
 import re
 
+import requests.exceptions
+
 from intelmq.lib.bot import CollectorBot
 from intelmq.lib.cache import Cache
 from intelmq.lib.utils import create_request_session
@@ -130,15 +132,18 @@ class ShadowServerAPICollectorBot(CollectorBot):
                 self.logger.debug('Processed file %r (fixed: %r) already.', filename, filename_fixed)
                 continue
             self.logger.debug('Processing file %r (fixed: %r).', filename, filename_fixed)
-            reportdata = self._report_download(item['id'])
-            report = self.new_report()
-            report.add('extra.file_name', filename_fixed)
-            report.add('raw', reportdata)
-            self.send_message(report)
-            self.cache.set(filename, 1)
-            self.logger.debug('Sent report: %r (fixed: %r, size: %.3g KiB).', filename, filename_fixed,
-                              len(reportdata) / 1024)  # TODO: Replace by a generic size-conversion function
-            reports_downloaded += 1
+            try:
+                reportdata = self._report_download(item['id'])
+                report = self.new_report()
+                report.add('extra.file_name', filename_fixed)
+                report.add('raw', reportdata)
+                self.send_message(report)
+                self.cache.set(filename, 1)
+                self.logger.debug('Sent report: %r (fixed: %r, size: %.3g KiB).', filename, filename_fixed,
+                                  len(reportdata) / 1024)  # TODO: Replace by a generic size-conversion function
+                reports_downloaded += 1
+            except requests.exceptions.ReadTimeout:
+                self.logger.error("Timeout on data download: %r, %r!", item['file'], item['id'])
         self.logger.info('Downloaded %d of %d available reports.', reports_downloaded, len(reportslist))
 
 
