@@ -39,6 +39,9 @@ class ShadowserverJSONParserBot(ParserBot):
                 self.logger.info('Could not determine the feed by the feed name %r given by parameter. '
                                  'Will determine the feed from the file names.', feedname)
 
+        if not hasattr(self.parameters, 'overwrite'):
+            setattr(self.parameters, 'overwrite', True)
+
     def parse(self, report):
         report_name = report.get('extra.file_name')
         if not report_name:
@@ -68,7 +71,7 @@ class ShadowserverJSONParserBot(ParserBot):
         processedkeys = []
 
         event = self.new_event(report)
-        event.add('feed.name', self.feedname)
+        event.add('feed.name', self.feedname, overwrite=self.parameters.overwrite)
 
         extra = {}
 
