@@ -4,8 +4,9 @@ The bot library has the base classes for all bots.
   * Bot: generic base class for all kind of bots
   * CollectorBot: base class for collectors
   * ParserBot: base class for parsers
-  * SQLBot: base classs for any bots using SQL
+  * SQLBot: base class for any bots using SQL
 """
+import argparse
 import atexit
 import csv
 import fcntl
@@ -149,7 +150,8 @@ class Bot(object):
                 self.logger.error('Multithreading is configured, but is not '
                                   'available for this bot. Look at the FAQ '
                                   'for a list of reasons for this. '
-                                  'https://github.com/certtools/intelmq/blob/master/docs/FAQ.md')
+                                  'https://intelmq.readthedocs.io/en/latest/user/FAQ.html'
+                                  '#multithreading-is-not-available-for-this-bot')
             elif (getattr(self.parameters, 'instances_threads', 1) > 1 and
                   disable_multithreading):
                 self.logger.warning('Multithreading is configured, but is not '
@@ -202,7 +204,7 @@ class Bot(object):
 
     def __handle_sigterm_signal(self, signum: int, stack: Optional[object]):
         """
-        Calles when a SIGTERM is received. Stops the bot.
+        Calls when a SIGTERM is received. Stops the bot.
         """
         self.logger.info("Received SIGTERM.")
         self.stop(exitcode=0)
@@ -212,9 +214,10 @@ class Bot(object):
         Called when signal is received and postpone.
         """
         self.__sighup.set()
-        self.logger.info('Received SIGHUP, initializing again later.')
         if not self.sighup_delay:
             self.__handle_sighup()
+        else:
+            self.logger.info('Received SIGHUP, initializing again later.')
 
     def __handle_sighup(self):
         """
@@ -631,11 +634,11 @@ class Bot(object):
         self.__current_message = None
 
     def _dump_message(self, error_traceback, message: dict):
-        self.logger.info('Dumping message to dump file.')
-
         if message is None or getattr(self.parameters, 'testing', False):
             return
 
+        self.logger.info('Dumping message to dump file.')
+
         dump_file = os.path.join(self.parameters.logging_path, self.__bot_id + ".dump")
 
         timestamp = datetime.utcnow()
@@ -696,6 +699,18 @@ class Bot(object):
 
         self.parameters.log_processed_messages_seconds = timedelta(seconds=self.parameters.log_processed_messages_seconds)
 
+        # TODO: Rewrite variables with env. variables ( CURRENT IMPLEMENTATION NOT FINAL )
+        if os.getenv('INTELMQ_IS_DOCKER', None):
+            pipeline_driver = os.getenv('INTELMQ_PIPELINE_DRIVER', None)
+            if pipeline_driver:
+                setattr(self.parameters, 'destination_pipeline_broker', pipeline_driver)
+                setattr(self.parameters, 'source_pipeline_broker', pipeline_driver)
+
+            pipeline_host = os.getenv('INTELMQ_PIPELINE_HOST', None)
+            if pipeline_host:
+                setattr(self.parameters, 'destination_pipeline_host', pipeline_host)
+                setattr(self.parameters, 'source_pipeline_host', pipeline_host)
+
     def __load_runtime_configuration(self):
         self.logger.debug("Loading runtime configuration from %r.", RUNTIME_CONF_FILE)
         config = utils.load_configuration(RUNTIME_CONF_FILE)
@@ -704,7 +719,7 @@ class Bot(object):
         if self.__bot_id in config:
             params = config[self.__bot_id]
             self.run_mode = params.get('run_mode', 'continuous')
-            for option, value in params['parameters'].items():
+            for option, value in params.get('parameters', {}).items():
                 setattr(self.parameters, option, value)
                 self.__log_configuration_parameter("runtime", option, value)
                 if option.startswith('logging_'):
@@ -718,6 +733,12 @@ class Bot(object):
             self.logger.handlers = []  # remove all existing handlers
             self.__init_logger()
 
+        # TODO: Rework
+        if os.getenv('INTELMQ_IS_DOCKER', None):
+            redis_cache_host = os.getenv('INTELMQ_REDIS_CACHE_HOST', None)
+            if redis_cache_host:
+                setattr(self.parameters, 'redis_cache_host', redis_cache_host)
+
     def __init_logger(self):
         """
         Initialize the logger.
@@ -728,7 +749,9 @@ class Bot(object):
             syslog = False
         self.logger = utils.log(self.__bot_id_full, syslog=syslog,
                                 log_path=self.parameters.logging_path,
-                                log_level=self.parameters.logging_level)
+                                log_level=self.parameters.logging_level,
+                                log_max_size=getattr(self.parameters, "logging_max_size", 0),
+                                log_max_copies=getattr(self.parameters, "logging_max_copies", None))
 
     def __load_pipeline_configuration(self):
         self.logger.debug("Loading pipeline configuration from %r.", PIPELINE_CONF_FILE)
@@ -771,11 +794,15 @@ class Bot(object):
         return libmessage.Event(*args, harmonization=self.harmonization, **kwargs)
 
     @classmethod
-    def run(cls):
-        if len(sys.argv) < 2:
+    def run(cls, parsed_args=None):
+
+        if not parsed_args:
+            parsed_args = cls._create_argparser().parse_args()
+
+        if not parsed_args.bot_id:
             sys.exit('No bot ID given.')
 
-        instance = cls(sys.argv[1])
+        instance = cls(parsed_args.bot_id)
         if not instance.is_multithreaded:
             instance.start()
 
@@ -853,6 +880,16 @@ class Bot(object):
         elif parameter_value:
             self.logger.debug('Extracting all files from archives.')
 
+    @classmethod
+    def _create_argparser(cls):
+        """
+        see https://github.com/certtools/intelmq/pull/1524/files#r464606370
+        why this code is not in the constructor
+        """
+        argparser = argparse.ArgumentParser(usage='%(prog)s [OPTIONS] BOT-ID')
+        argparser.add_argument('bot_id', nargs='?', metavar='BOT-ID', help='unique bot-id of your choosing')
+        return argparser
+
 
 class ParserBot(Bot):
     csv_params = {}
@@ -993,7 +1030,7 @@ class ParserBot(Bot):
             if self._Bot__destination_queues and '_on_error' in self._Bot__destination_queues:
                 self.send_message(report_dump, path='_on_error')
 
-        self.logger.info('Sent %d events and found %d problem(s).' % (events_count, len(self.__failed)))
+        self.logger.info('Sent %d events and found %d problem(s).', events_count, len(self.__failed))
 
         self.acknowledge_message()
 
@@ -1050,6 +1087,7 @@ class ParserBot(Bot):
         writer = csv.DictWriter(out, self.csv_fieldnames, **self.csv_params)
         writer.writeheader()
         out.write(self.current_line)
+
         return out.getvalue().strip()
 
     def recover_line_json(self, line: dict):
@@ -1060,13 +1098,13 @@ class ParserBot(Bot):
         """
         return json.dumps([line])
 
-    def recover_line_json_stream(self, line: dict) -> str:
+    def recover_line_json_stream(self, line=None) -> str:
         """
         recover_line for json streams, just returns the current line, unparsed.
 
         Parameters
         ----------
-        line : dict
+        line : None, not required, only for compatibility with other recover_line methods
 
         Returns
         -------
