@@ -21,20 +21,21 @@ EXAMPLE_EVENT = {"feed.name": "Sample CSV Feed",
                  "time.source": "2018-08-01T07:49:41+00:00",
                  "classification.type": "malware",
                  "source.ip": "127.0.0.1",
-                 "raw": utils.base64_encode(SAMPLE_SPLIT[0]+'\r\n'),
+                 "raw": utils.base64_encode(SAMPLE_SPLIT[0] + '\r\n'),
                  "time.observation": "2015-01-01T00:00:00+00:00",
                  }
 EXAMPLE_EVENT2 = EXAMPLE_EVENT.copy()
 EXAMPLE_EVENT2['source.fqdn'] = "example.com"
-EXAMPLE_EVENT2["raw"] = utils.base64_encode(SAMPLE_SPLIT[1]+'\r\n')
+EXAMPLE_EVENT2["raw"] = utils.base64_encode(SAMPLE_SPLIT[1] + '\r\n')
 
 EXAMPLE_EVENT3 = EXAMPLE_EVENT.copy()
 del EXAMPLE_EVENT3['source.ip']
 EXAMPLE_EVENT3['source.fqdn'] = "example.com"
-EXAMPLE_EVENT3["raw"] = utils.base64_encode(SAMPLE_SPLIT[2]+'\r\n')
+EXAMPLE_EVENT3["raw"] = utils.base64_encode(SAMPLE_SPLIT[2] + '\r\n')
 
 EXAMPLE_EVENT4 = EXAMPLE_EVENT.copy()
-EXAMPLE_EVENT4["raw"] = utils.base64_encode(SAMPLE_SPLIT[3]+'\r\n')
+EXAMPLE_EVENT4["raw"] = utils.base64_encode(SAMPLE_SPLIT[3] + '\r\n')
+
 
 class TestGenericCsvParserBot(test.BotTestCase, unittest.TestCase):
     """
@@ -59,7 +60,7 @@ class TestGenericCsvParserBot(test.BotTestCase, unittest.TestCase):
         self.assertMessageEqual(1, EXAMPLE_EVENT2)
         self.assertMessageEqual(2, EXAMPLE_EVENT3)
         self.assertLogMatches("Failed to parse line.")
-        self.assertLogMatches("intelmq.lib.exceptions.InvalidValue: invalid value '.' \(<class 'str'>\) for key 'source.fqdn'")
+        self.assertLogMatches(r"intelmq.lib.exceptions.InvalidValue: invalid value '.' \(<class 'str'>\) for key 'source.fqdn'")
 
     def test_error_ignore(self):
         self.sysconfig = {"columns": ["time.source", "source.ip",
