@@ -143,8 +143,10 @@ class TestRedis(unittest.TestCase):
     def setUp(self):
         params = Parameters()
         params.broker = 'Redis'
+        setattr(params, 'source_pipeline_host', os.getenv('INTELMQ_PIPELINE_HOST', 'localhost'))
         setattr(params, 'source_pipeline_password', os.getenv('INTELMQ_TEST_REDIS_PASSWORD'))
         setattr(params, 'source_pipeline_db', 4)
+        setattr(params, 'destination_pipeline_host', os.getenv('INTELMQ_PIPELINE_HOST', 'localhost'))
         setattr(params, 'destination_pipeline_password', os.getenv('INTELMQ_TEST_REDIS_PASSWORD'))
         setattr(params, 'destination_pipeline_db', 4)
         logger = logging.getLogger('foo')
@@ -266,9 +268,8 @@ class TestAmqp(unittest.TestCase):
         self.pipe.reject_message()
         self.assertEqual(SAMPLES['normal'][1], self.pipe.receive())
 
-    @unittest.skipIf(os.getenv('TRAVIS') == 'true' and os.getenv('CI') == 'true'
-                     and sys.version_info[:2] == (3, 8),
-                     'Fails on Travis with Python 3.8')
+    @unittest.skipIf(os.getenv('CI') == 'true' and sys.version_info[:2] == (3, 8),
+                     'Fails on CI with Python 3.8')
     def test_acknowledge(self):
         self.pipe.send(SAMPLES['normal'][0])
         self.pipe.receive()
